@@ -41,6 +41,7 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
     FIELD_DST_PORT      = "dst_port"
     FIELD_DST_NETWORK   = "dst_network"
     FIELD_DST_HOST      = "simple_host"
+    FIELD_APPIMAGE      = "appimage_path"
 
     DURATION_30s    = "30s"
     DURATION_5m     = "5m"
@@ -49,6 +50,8 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
     DURATION_1h     = "1h"
     # don't translate
 
+    APPIMAGE_PREFIX = "/tmp/.mount_"
+
     # label displayed in the pop-up combo
     DURATION_session = QC.translate("popups", "until reboot")
     # label displayed in the pop-up combo
@@ -322,6 +325,20 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             self.argsLabel.setVisible(False)
             self.argsLabel.setText("")
 
+    def _set_default_target(self, combo, con, app_name, app_args):
+        # set appimage as default target if the process path starts with
+        # /tmp/._mount
+        if con.process_path.startswith(self.APPIMAGE_PREFIX):
+            idx = combo.findData(self.FIELD_APPIMAGE)
+            if idx != -1:
+                combo.setCurrentIndex(idx)
+                return
+
+        if int(con.process_id) > 0 and app_name != "" and app_args != "":
+            self.whatCombo.setCurrentIndex(int(self._cfg.getSettings(self._cfg.DEFAULT_TARGET_KEY)))
+        else:
+            self.whatCombo.setCurrentIndex(2)
+
     def _render_connection(self, con):
         app_name, app_icon, description, _ = self._apps_parser.get_info_by_path(con.process_path, "terminal")
         app_args = " ".join(con.process_args)
@@ -389,6 +406,10 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             self.whatCombo.model().item(4).setEnabled(False)
 
         self.whatCombo.addItem(QC.translate("popups", "from this PID"), self.FIELD_PROC_ID)
+        #######################
+
+        if con.process_path.startswith(self.APPIMAGE_PREFIX):
+            self._add_appimage_pattern_to_combo(self.whatCombo, con)
 
         self._add_dst_networks_to_combo(self.whatCombo, con.dst_ip)
 
@@ -409,11 +430,7 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
 
         self._configure_default_duration()
 
-        if int(con.process_id) > 0:
-            self.whatCombo.setCurrentIndex(int(self._cfg.getSettings(self._cfg.DEFAULT_TARGET_KEY)))
-        else:
-            self.whatCombo.setCurrentIndex(2)
-
+        self._set_default_target(self.whatCombo, con, app_name, app_args)
 
         self.checkDstIP.setChecked(self._cfg.getBool(self._cfg.DEFAULT_POPUP_ADVANCED_DSTIP))
         self.checkDstPort.setChecked(self._cfg.getBool(self._cfg.DEFAULT_POPUP_ADVANCED_DSTPORT))
@@ -437,6 +454,17 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         self._send_rule()
         e.ignore()
 
+    def _add_appimage_pattern_to_combo(self, combo, con):
+        """appimages' absolute path usually starts with /tmp/.mount_
+        """
+        appimage_bin = os.path.basename(con.process_path)
+        appimage_path = os.path.dirname(con.process_path)
+        appimage_path = appimage_path[0:len(self.APPIMAGE_PREFIX)+6]
+        combo.addItem(
+            QC.translate("popups", "from {0}*/{1}").format(appimage_path, appimage_bin),
+            self.FIELD_APPIMAGE
+        )
+
     def _add_dst_networks_to_combo(self, combo, dst_ip):
         if type(ipaddress.ip_address(dst_ip)) == ipaddress.IPv4Address:
             combo.addItem(QC.translate("popups", "to {0}").format(ipaddress.ip_network(dst_ip + "/24", strict=False)),  self.FIELD_DST_NETWORK)
@@ -530,27 +558,27 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         else:
             return Config.DURATION_ALWAYS
 
-    def _get_combo_operator(self, combo, what_idx):
+    def _get_combo_operator(self, combo, what_idx, con):
         if combo.itemData(what_idx) == self.FIELD_PROC_PATH:
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_PATH, self._con.process_path
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_PATH, con.process_path
 
         elif combo.itemData(what_idx) == self.FIELD_PROC_ARGS:
             # this should not happen
-            if len(self._con.process_args) == 0 or self._con.process_args[0] == "":
-                return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_PATH, self._con.process_path
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_COMMAND, ' '.join(self._con.process_args)
+            if len(con.process_args) == 0 or con.process_args[0] == "":
+                return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_PATH, con.process_path
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_COMMAND, ' '.join(con.process_args)
 
         elif combo.itemData(what_idx) == self.FIELD_PROC_ID:
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_ID, "{0}".format(self._con.process_id)
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_PROCESS_ID, "{0}".format(con.process_id)
 
         elif combo.itemData(what_idx) == self.FIELD_USER_ID:
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_USER_ID, "%s" % self._con.user_id
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_USER_ID, "%s" % con.user_id
 
         elif combo.itemData(what_idx) == self.FIELD_DST_PORT:
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_DEST_PORT, "%s" % self._con.dst_port
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_DEST_PORT, "%s" % con.dst_port
 
         elif combo.itemData(what_idx) == self.FIELD_DST_IP:
-            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_DEST_IP, self._con.dst_ip
+            return Config.RULE_TYPE_SIMPLE, Config.OPERAND_DEST_IP, con.dst_ip
 
         elif combo.itemData(what_idx) == self.FIELD_DST_HOST:
             return Config.RULE_TYPE_SIMPLE, Config.OPERAND_DEST_HOST, combo.currentText()
@@ -575,6 +603,12 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             text = parts[len(parts)-1]
             return Config.RULE_TYPE_REGEXP, Config.OPERAND_DEST_IP, "%s" % r'\.'.join(text.split('.')).replace("*", ".*")
 
+        elif combo.itemData(what_idx) == self.FIELD_APPIMAGE:
+            appimage_bin = os.path.basename(con.process_path)
+            appimage_path = os.path.dirname(con.process_path).replace(".", "\.")
+            appimage_path = appimage_path[0:len(self.APPIMAGE_PREFIX)+7]
+            return Config.RULE_TYPE_REGEXP, Config.OPERAND_PROCESS_PATH, r'^{0}[0-9A-Za-z]{{6}}\/.*{1}$'.format(appimage_path, appimage_bin)
+
     def _on_action_clicked(self, action):
         self._default_action = action
         self._send_rule()
@@ -613,7 +647,7 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                 self._rule.action = Config.ACTION_REJECT
 
             what_idx = self.whatCombo.currentIndex()
-            self._rule.operator.type, self._rule.operator.operand, self._rule.operator.data = self._get_combo_operator(self.whatCombo, what_idx)
+            self._rule.operator.type, self._rule.operator.operand, self._rule.operator.data = self._get_combo_operator(self.whatCombo, what_idx, self._con)
             if self._rule.operator.data == "":
                 print("Invalid rule, discarding: ", self._rule)
                 self._rule = None
@@ -625,7 +659,7 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             # TODO: move to a method
             data=[]
             if self.checkDstIP.isChecked() and self.whatCombo.itemData(what_idx) != self.FIELD_DST_IP:
-                _type, _operand, _data = self._get_combo_operator(self.whatIPCombo, self.whatIPCombo.currentIndex())
+                _type, _operand, _data = self._get_combo_operator(self.whatIPCombo, self.whatIPCombo.currentIndex(), self._con)
                 data.append({"type": _type, "operand": _operand, "data": _data})
                 rule_temp_name = slugify("%s %s" % (rule_temp_name, _data))
 
@@ -640,12 +674,13 @@ class PromptDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             is_list_rule = self._is_list_rule()
 
             # If the user has selected to filter by cmdline, but the launched
-            # command path is not absolute, we can't trust it. In this case,
-            # also filter by the absolute path to the binary.
+            # command path is not absolute or the first component contains
+            # "/proc/" (/proc/self/fd.., /proc/1234/fd...), we can't trust it.
+            # In these cases, also filter by the absolute path to the binary.
             if self._rule.operator.operand == Config.OPERAND_PROCESS_COMMAND:
                 proc_args = " ".join(self._con.process_args)
                 proc_args = proc_args.split(" ")
-                if os.path.isabs(proc_args[0]) == False:
+                if os.path.isabs(proc_args[0]) == False or proc_args[0].startswith("/proc"):
                     is_list_rule = True
                     data.append({"type": Config.RULE_TYPE_SIMPLE, "operand": Config.OPERAND_PROCESS_PATH, "data": str(self._con.process_path)})
 
